@@ -4,7 +4,7 @@ use 5.010;
 use utf8;
 use namespace::autoclean;
 use parent 'App::Sqitch::Plan::Line';
-use Moose;
+use Mouse;
 
 has value => (
     is       => 'ro',
@@ -50,7 +50,7 @@ sub as_string {
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
+no Mouse;
 
 __END__
 
